@@ -2,7 +2,7 @@
 context("messages")
 
 test_that("messages in callr::r do not crash session", {
-  ret <- r(function() { cliapp::cli_text("fooobar"); 1 + 1 })
+  ret <- r(function() { cli::cli_text("fooobar"); 1 + 1 })
   expect_identical(ret, 2)
   gc()
 })
@@ -11,7 +11,7 @@ test_that("messages in callr::r_bg do not crash session", {
   skip_in_covr()  # TODO: what wrong with this on Windows?
   skip_on_cran()
 
-  rx <- r_bg(function() { cliapp::cli_text("fooobar"); 1 + 1 })
+  rx <- r_bg(function() { cli::cli_text("fooobar"); 1 + 1 })
   rx$wait(5000)
   rx$kill()
   expect_equal(rx$get_exit_status(), 0)
